@@ -26,7 +26,7 @@ our %EXPORT_TAGS = (
 	'consts'  => [ grep /^PASSWORD_/, @EXPORT_OK ],
 	'funcs'   => [ grep /^password_/, @EXPORT_OK ],
 );
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 
 # Exported constants
@@ -123,7 +123,7 @@ Functional interface use, using options:
 	my $pepper = 'Abracadabra and Hocus pocus';  # retrieve this from a secrets config file for example (and don't loose it!)
 	my $peppered_password = hmac_sha256($password, $pepper);
 	my $crypted_string = password_hash($password, PASSWORD_ARGON2ID);  # store this in your database
-	# ... and when verifying passwords, then you pepper then first too.
+	# ... and when verifying passwords, then you pepper them first too.
 
 Class method use, using options:
 
@@ -308,7 +308,7 @@ sub password_hash {
 	}
 	elsif (($algo == PASSWORD_ARGON2ID) || ($algo == PASSWORD_ARGON2I)) {
 		unless ($INC{'Crypt/Argon2.pm'} || eval { require Crypt::Argon2; }) {
-			my $algo_const_name = $algo == PASSWORD_ARGON2ID ? PASSWORD_ARGON2ID : PASSWORD_ARGON2I;
+			my $algo_const_name = $algo == PASSWORD_ARGON2ID ? $SIG_ARGON2ID : $SIG_ARGON2I;
 			croak("Cannot use the $algo_const_name algorithm because the module Crypt::Argon2 is not installed");
 		}
 		my $salt = $options{'salt'} || Crypt::OpenSSL::Random::random_bytes($PASSWORD_ARGON2_DEFAULT_SALT_LENGTH);	# undocumented; not a PHP option; raw!
@@ -347,7 +347,7 @@ sub password_needs_rehash {
 	my $crypted = shift;
 	my $algo = shift(@_) // PASSWORD_DEFAULT;
 	my %options = @_ && ref($_[0]) ? %{$_[0]} : @_;
-	my %info = password_get_info($crypted);
+	my %info = $proto->password_get_info($crypted);
 	unless ($info{'algo'} == $algo) {
 		$options{'debug'} && warn('Algorithms differ: ' . $info{'algo'} . "<>$algo");
 		return 1;
@@ -561,9 +561,9 @@ __END__
 
 =head1 SEE ALSO
 
+ L<Crypt::Argon2> recommended for argon2 algorithm support.
  L<Crypt::Bcrypt> used for all the bcrypt support.
  L<Crypt::OpenSSL::Random> used for random salt generation.
- L<Crypt::Argon2> recommended for argon2 algorithm support.
 
 =head1 COPYRIGHT
 
